package gs;

object Gs {
  /**
    * Standard compiler options used by GS projects.
    */
  val CompilerOptions: Seq[String] = Seq(
    "-encoding",
    "utf8",         // Set source file character encoding.
    "-deprecation", // Emit warning and location for usages of deprecated APIs.
    "-feature", // Emit warning and location for usages of features that should be imported explicitly.
    "-explain", // Explain errors in more detail.
    "-unchecked", // Enable additional warnings where generated code depends on assumptions.
    "-explain-types",           // Explain type errors in more detail.
    "-Xfatal-warnings",         // Fail the compilation if there are any warnings.
    "-language:strictEquality", // Enable multiversal equality (require CanEqual)
    "-Wunused:implicits",       // Warn if an implicit parameter is unused.
    "-Wunused:explicits",       // Warn if an explicit parameter is unused.
    "-Wunused:imports",         // Warn if an import selector is not referenced.
    "-Wunused:locals",          // Warn if a local definition is unused.
    "-Wunused:privates",        // Warn if a private member is unused.
    "-Ysafe-init" // Enable the experimental safe initialization check.
  )

  /**
    * Definition of the Apache 2.0 license. This is the default license for GS
    * open source projects.
    */
  val Apache2: (String, java.net.URL) =
    "Apache 2.0" -> sbt.url("https://www.apache.org/licenses/LICENSE-2.0.html")

  /**
    * Host of the GS Git server.
    */
  val GitHost: String = "git.garrity.co"

  /**
    * Organization name used to organize projects in Git.
    */
  val GitOrganization: String = "garrity-software"

  /**
    * Calculate the Git repository for a project.
    *
    * @param projectName The project name.
    * @return The HTTPS Git repository URL.
    */
  def gitRepo(projectName: String): String = 
    s"https://$GitHost/$GitOrganization/$projectName"

  /**
    * Calculate the Git SSH target for a project.
    *
    * @param projectName The project name.
    * @return The SSH target.
    */
  def gitSsh(projectName: String): String =
    s"git@$GitHost:$GitOrganization/${projectName}.git"
}
